import { Balances, Chain, ChainsConfig, Network, PlatformContext, SignedTx, TokenId, TxHash } from '@wormhole-foundation/connect-sdk';
import { SolanaChain } from './chain';
import { Commitment, Connection } from '@solana/web3.js';
import { AnySolanaAddress, SolanaChains, SolanaPlatformType } from './types';
/**
 * @category Solana
 */
export declare class SolanaPlatform<N extends Network> extends PlatformContext<N, SolanaPlatformType> {
    static _platform: "Solana";
    constructor(network: N, config?: ChainsConfig<N, SolanaPlatformType>);
    getRpc<C extends SolanaChains>(chain: C, commitment?: Commitment): Connection;
    getChain<C extends SolanaChains>(chain: C, rpc?: Connection): SolanaChain<N, C>;
    static nativeTokenId<N extends Network, C extends SolanaChains>(network: N, chain: C): TokenId<C>;
    static isNativeTokenId<N extends Network, C extends SolanaChains>(network: N, chain: C, tokenId: TokenId): boolean;
    static isSupportedChain(chain: Chain): boolean;
    static getDecimals(chain: Chain, rpc: Connection, token: AnySolanaAddress | 'native'): Promise<bigint>;
    static getBalance(chain: Chain, rpc: Connection, walletAddress: string, token: AnySolanaAddress | 'native'): Promise<bigint | null>;
    static getBalances(chain: Chain, rpc: Connection, walletAddress: string, tokens: (AnySolanaAddress | 'native')[]): Promise<Balances>;
    static sendWait(chain: Chain, rpc: Connection, stxns: SignedTx[]): Promise<TxHash[]>;
    static getLatestBlock(rpc: Connection): Promise<number>;
    static getLatestFinalizedBlock(rpc: Connection): Promise<number>;
    static chainFromChainId(genesisHash: string): [Network, SolanaChains];
    static chainFromRpc(rpc: Connection): Promise<[Network, SolanaChains]>;
}
//# sourceMappingURL=platform.d.ts.map