import { Keypair } from '@solana/web3.js';
import { encoding, } from '@wormhole-foundation/connect-sdk';
import { SolanaPlatform } from '../platform';
// returns a SignOnlySigner for the Solana platform
export async function getSolanaSigner(rpc, privateKey) {
    const [_, chain] = await SolanaPlatform.chainFromRpc(rpc);
    return new SolanaSigner(chain, Keypair.fromSecretKey(encoding.b58.decode(privateKey)));
}
export class SolanaSigner {
    _chain;
    _keypair;
    constructor(_chain, _keypair) {
        this._chain = _chain;
        this._keypair = _keypair;
    }
    chain() {
        return this._chain;
    }
    address() {
        return this._keypair.publicKey.toBase58();
    }
    async sign(tx) {
        const signed = [];
        for (const txn of tx) {
            const { description, transaction } = txn;
            console.log(`Signing: ${description} for ${this.address()}`);
            // Uncomment for debug
            // const st = transaction as Transaction;
            // console.log(st.signatures);
            // console.log(st.feePayer);
            // st.instructions.forEach((ix) => {
            //   console.log('Program', ix.programId.toBase58());
            //   console.log('Data: ', ix.data.toString('hex'));
            //   ix.keys.forEach((k) => {
            //     console.log(k, k.pubkey.toBase58());
            //   });
            // });
            transaction.partialSign(this._keypair);
            signed.push(transaction.serialize());
        }
        return signed;
    }
}
//# sourceMappingURL=signer.js.map